using System.Collections.Generic;
using System.Web.Routing;
using Nop.Core.Domain.Cms;
using Nop.Core.Plugins;
using Nop.Services.Cms;
using Nop.Services.Localization;
using Nop.Services.Configuration;
using Nop.Core.Domain.Tasks;
using Nop.Services.Tasks;
using Nop.Core.Data;
using System.Linq;
using Nop.Services.Common;

namespace Nop.Plugin.Widgets.EKomi
{
    /// <summary>
    /// Live person provider
    /// </summary>
    public class EKomiPlugin : BasePlugin, IWidgetPlugin, IMiscPlugin
    {
        private readonly ISettingService _settingService;
        private readonly IRepository<ScheduleTask> _scheduleTaskRepository;

        public EKomiPlugin(ISettingService settingService,
            IRepository<ScheduleTask> scheduleTaskRepository)
        {
            this._settingService = settingService;
            this._scheduleTaskRepository = scheduleTaskRepository;
        }

        /// <summary>
        /// Get a list of supported widget zones; if empty list is returned, then all zones are supported
        /// </summary>
        /// <returns>A list of supported widget zones</returns>
        public IList<WidgetZone> SupportedWidgetZones()
        {
            //limit widget to the following zones
            return new List<WidgetZone>() 
            { 
                WidgetZone.BeforeLeftSideColumn, 
                WidgetZone.AfterLeftSideColumn, 
                WidgetZone.BeforeRightSideColumn, 
                WidgetZone.AfterRightSideColumn
            };
        }

        public void GetConfigurationRoute(out string actionName, out string controllerName, out RouteValueDictionary routeValues)
        {
            actionName = "Configure";
            controllerName = "WidgetsEKomi";
            routeValues = new RouteValueDictionary() { { "Namespaces", "Nop.Plugin.Misc.EKomi.Controllers" }, { "area", null } };
        }


        /// <summary>
        /// Gets a route for provider configuration
        /// </summary>
        /// <param name="widgetId">Widget identifier</param>
        /// <param name="actionName">Action name</param>
        /// <param name="controllerName">Controller name</param>
        /// <param name="routeValues">Route values</param>
        public void GetConfigurationRoute(int widgetId, out string actionName, out string controllerName, out RouteValueDictionary routeValues)
        {
            actionName = "ConfigureWidget";
            controllerName = "WidgetsEKomi";
            routeValues = new RouteValueDictionary() { { "Namespaces", "Nop.Plugin.Widgets.EKomi.Controllers" }, { "area", null }, { "widgetId", widgetId } };
        }

        /// <summary>
        /// Gets a route for displaying widget
        /// </summary>
        /// <param name="widgetId">Widget identifier</param>
        /// <param name="actionName">Action name</param>
        /// <param name="controllerName">Controller name</param>
        /// <param name="routeValues">Route values</param>
        public void GetDisplayWidgetRoute(int widgetId, out string actionName, out string controllerName, out RouteValueDictionary routeValues)
        {
            actionName = "PublicInfo";
            controllerName = "WidgetsEKomi";
            routeValues = new RouteValueDictionary() { { "Namespaces", "Nop.Plugin.Widgets.EKomi.Controllers" }, { "area", null }, { "widgetId", widgetId } };
        }

        /// <summary>
        /// Install plugin
        /// </summary>
        public override void Install()
        {
            ScheduleTask t = (from ee in _scheduleTaskRepository.Table
                     where ee.Type == "Nop.Plugin.Widgets.EKomi.RefreshFeedbackTask, Nop.Plugin.Widgets.EKomi"
                     select ee).FirstOrDefault();

            if (t == null)
            {
                t = new ScheduleTask()
                    {
                        Name = "Refresh EKomi Feedback",
                        Seconds = 300,
                        Type = "Nop.Plugin.Widgets.EKomi.RefreshFeedbackTask, Nop.Plugin.Widgets.EKomi",
                        Enabled = true,
                        StopOnError = false,
                    };

                _scheduleTaskRepository.Insert(t);
            }

            this.AddOrUpdatePluginLocaleResource("Plugins.Widgets.EKomi.Feedback", "Feedback");

            this.AddOrUpdatePluginLocaleResource("Plugins.Widgets.EKomi.InterfaceId", "Interface id");
            this.AddOrUpdatePluginLocaleResource("Plugins.Widgets.EKomi.InterfaceId.Hint", "Enter your interface id here (you can find it in the eKomi back office).");
            this.AddOrUpdatePluginLocaleResource("Plugins.Widgets.EKomi.InterfacePassword", "Interface password");
            this.AddOrUpdatePluginLocaleResource("Plugins.Widgets.EKomi.InterfacePassword.Hint", "Enter your interface password here (you can find it in the eKomi back office).");

            this.AddOrUpdatePluginLocaleResource("Plugins.Widgets.EKomi.DisplayFeedback", "Display comments feedback");
            this.AddOrUpdatePluginLocaleResource("Plugins.Widgets.EKomi.DisplayFeedback.Hint", "Check to display comments feedback");
            this.AddOrUpdatePluginLocaleResource("Plugins.Widgets.EKomi.DisplayRating", "Display feedback rating");
            this.AddOrUpdatePluginLocaleResource("Plugins.Widgets.EKomi.DisplayRating.Hint", "Check to display feedback rating");
            this.AddOrUpdatePluginLocaleResource("Plugins.Widgets.EKomi.DisplayStars", "Display feedback stars");
            this.AddOrUpdatePluginLocaleResource("Plugins.Widgets.EKomi.DisplayStars.Hint", "Check to display feedback stars");
            this.AddOrUpdatePluginLocaleResource("Plugins.Widgets.EKomi.CommentsNumber", "Number of comments to display");
            this.AddOrUpdatePluginLocaleResource("Plugins.Widgets.EKomi.CommentsNumber.Hint", "Enter the number of comments to display (random)");
        
            this.AddOrUpdatePluginLocaleResource("Plugins.Widgets.EKomi.DisplayScript", "Display eKomi script");
            this.AddOrUpdatePluginLocaleResource("Plugins.Widgets.EKomi.DisplayScript.Hint", "Check to display eKomi script");
            this.AddOrUpdatePluginLocaleResource("Plugins.Widgets.EKomi.WidgetScript", "Widget script");
            this.AddOrUpdatePluginLocaleResource("Plugins.Widgets.EKomi.WidgetScript.Hint", "Enter your widget script here (you can find it in the eKomi back office).");

            base.Install();
        }

        public override void Uninstall()
        {
            ScheduleTask t = (from ee in _scheduleTaskRepository.Table
                              where ee.Type == "Nop.Plugin.Widgets.EKomi.RefreshFeedbackTask, Nop.Plugin.Widgets.EKomi"
                              select ee).FirstOrDefault();

            if (t != null)
            {
                _scheduleTaskRepository.Delete(t);
            }


            base.Uninstall();
        }



    }
}
